@@ -12,7 +12,8 @@ from pydantic_cli import run_and_exit
 
 class Options(BaseModel):
     input_file: str
-    run_training: bool = False
+    run_training: bool = True
+    dry_run: bool = False
 
 
 def example_runner(opts: Options) -> int:
